@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Philip Blundell <philb@gnu.org>
+ * Copyright (C) 2004, 2006 Philip Blundell <philb@gnu.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 #include <mimedir/mimedir-vcard.h>
 
 #include <gpe/vcard.h>
+#include <gpe/contacts-db.h>
 
 #include <sqlite.h>
 
@@ -47,6 +48,9 @@ do_import_vcard (MIMEDirVCard *card)
   char *given_name = NULL;
   char *company = NULL;
 
+  contacts_db_open (FALSE);
+  contacts_db_close ();
+
   home = g_get_home_dir ();
   
   buf = g_strdup_printf ("%s%s", home, DB_NAME);
